package Distros;
use strict;

require Exporter;
@Distros::ISA = qw(Exporter);
# Exported symbols
push @Distros::EXPORT, qw(
    &guess_platform &guess_package_manager &does_shell_know &trim
);

#----------------------------------------------------------------------------

# Helps to determine platform name.
sub guess_platform($ )
{
    my $name = $_[0];

    if ( $name =~ /^(amd64|x86_64)$/)
        { return "x86-64" }
    elsif ( $name =~ /^(ia32|i[3-6]86|x86)$/ )
        { return "IA32" }
    elsif ( $name =~ /^(ia64)$/ )
        { return "IA64" }
    elsif ( $name =~ /^(ppc|ppc32)$/ )
        { return "PPC32" }
    elsif ( $name =~ /^(ppc64)$/ )
        { return "PPC64" }
    elsif ( $name =~ /^(s390)$/ )
        { return "S390" }
    elsif ( $name =~ /^(s390x)$/ )
        { return "S390X" }
    else
        { return "unknown"; }
}

#----------------------------------------------------------------------------

# Determines which package manager to use.
sub guess_package_manager {
	my $host_os = `lsb_release -s -d`;
    $host_os =~ s/\"(.*)\"/$1/;
	chomp($host_os);

    if ( $host_os =~ /(suse|red\W?hat|asianux|mandriva)/i )
    {
        # Distros known to be rpm-based
        return "rpm";
    }
    elsif ( $host_os =~ /(ubuntu|debian)/i )
    {
        # Distros known to use apt and dpkg
		# (note that on some Debian-based systems, like Xandros, `lsb_release` gives us 'Debian')
        return "dpkg";
    }
	elsif ( does_shell_know ("emerge") ) {
		# Gentoo
		return "emerge";
	}
    else {
		# Do we have 'dpkg'? Some systems may have both rpm and dpkg,
		# and 'dpkg' is usually the default manager in this case
        if ( does_shell_know ("dpkg") ) {
            return "dpkg";
        }
        elsif ( does_shell_know ("rpm") ) {
            return "rpm";
        }
    }

    return "unknown";
}

#----------------------------------------------------------------------------

# Checks whether the specified tool is known to the shell.
sub does_shell_know
{
    my $tool_name = shift;
    return (system ("which $tool_name >/dev/null 2>/dev/null") == 0);
}

# Trim string spaces.
sub trim($)
{
	my $string = shift;
	$string =~ s/^\s+//;
	$string =~ s/\s+$//;
	return $string;
}

